<?php
/**
 * VW Driving School Theme Customizer
 *
 * @package VW Driving School
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_driving_school_customize_register( $wp_customize ) {

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_driving_school_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-driving-school' ),
	    'description' => __( 'Description of what this panel does.', 'vw-driving-school' ),
	) );

	$wp_customize->add_section( 'vw_driving_school_left_right', array(
    	'title'      => __( 'General Settings', 'vw-driving-school' ),
		'priority'   => 30,
		'panel' => 'vw_driving_school_panel_id'
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_driving_school_theme_options',array(
        'default' => __('Right Sidebar','vw-driving-school'),
        'sanitize_callback' => 'vw_driving_school_sanitize_choices'	        
	));
	$wp_customize->add_control('vw_driving_school_theme_options',array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-driving-school'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-driving-school'),
        'section' => 'vw_driving_school_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-driving-school'),
            'Right Sidebar' => __('Right Sidebar','vw-driving-school'),
            'One Column' => __('One Column','vw-driving-school'),
            'Three Columns' => __('Three Columns','vw-driving-school'),
            'Four Columns' => __('Four Columns','vw-driving-school'),
            'Grid Layout' => __('Grid Layout','vw-driving-school')
        ),
	) );

	$wp_customize->add_setting('vw_driving_school_page_layout',array(
        'default' => __('Right Sidebar','vw-driving-school'),
        'sanitize_callback' => 'vw_driving_school_sanitize_choices'	        
	));
	$wp_customize->add_control('vw_driving_school_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-driving-school'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-driving-school'),
        'section' => 'vw_driving_school_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-driving-school'),
            'Right Sidebar' => __('Right Sidebar','vw-driving-school'),
            'One Column' => __('One Column','vw-driving-school')
        ),
	) );

	//Topbar
	$wp_customize->add_section( 'vw_driving_school_topbar', array(
    	'title'      => __( 'Topbar Settings', 'vw-driving-school' ),
		'priority'   => 30,
		'panel' => 'vw_driving_school_panel_id'
	) );

	$wp_customize->add_setting('vw_driving_school_discount_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_driving_school_discount_text',array(
		'label'	=> __('Add Discount Text','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( 'Lorem Ipsum is simply dummy text of the printing.', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_driving_school_booking_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_driving_school_booking_text',array(
		'label'	=> __('Add Button Text','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( 'BOOK A CLASS', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_driving_school_booking_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('vw_driving_school_booking_link',array(
		'label'	=> __('Add Button Link','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( 'http://www.example.com', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_topbar',		
		'type'=> 'url'
	));
    
	//Slider
	$wp_customize->add_section( 'vw_driving_school_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-driving-school' ),
		'priority'   => null,
		'panel' => 'vw_driving_school_panel_id'
	) );

	$wp_customize->add_setting('vw_driving_school_slider_arrows',array(
       'default' => 'false',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('vw_driving_school_slider_arrows',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide slider','vw-driving-school'),
       'section' => 'vw_driving_school_slidersettings',
    ));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'vw_driving_school_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_driving_school_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_driving_school_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'vw-driving-school' ),
			'description' => __('Slider image size (1500 x 590)','vw-driving-school'),
			'section'  => 'vw_driving_school_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//Contact Section
	$wp_customize->add_section( 'vw_driving_school_contact_section' , array(
    	'title'      => __( 'Contact us', 'vw-driving-school' ),
		'priority'   => null,
		'panel' => 'vw_driving_school_panel_id'
	) );

	$wp_customize->add_setting('vw_driving_school_phone',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_driving_school_phone',array(
		'label'	=> __('Add Phone no.','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( '+00 123 456 7890', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_contact_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_driving_school_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_driving_school_email_address',array(
		'label'	=> __('Add Email Address','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( 'support@example.com', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_contact_section',
		'type'=> 'text'
	));

	//About Section
	$wp_customize->add_section( 'vw_driving_school_about_section' , array(
    	'title'      => __( 'About us', 'vw-driving-school' ),
		'priority'   => null,
		'panel' => 'vw_driving_school_panel_id'
	) );

	$wp_customize->add_setting( 'vw_driving_school_about_page', array(
		'default'           => '',
		'sanitize_callback' => 'vw_driving_school_sanitize_dropdown_pages'
	) );
	$wp_customize->add_control( 'vw_driving_school_about_page', array(
		'label'    => __( 'About Page', 'vw-driving-school' ),
		'description' => __('Image size (1500 x 590)','vw-driving-school'),
		'section'  => 'vw_driving_school_about_section',
		'type'     => 'dropdown-pages'
	) );

	//Footer Text
	$wp_customize->add_section('vw_driving_school_footer',array(
		'title'	=> __('Footer','vw-driving-school'),
		'description'=> __('This section will appear in the footer','vw-driving-school'),
		'panel' => 'vw_driving_school_panel_id',
	));	
	
	$wp_customize->add_setting('vw_driving_school_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_driving_school_footer_text',array(
		'label'	=> __('Copyright Text','vw-driving-school'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2018......', 'vw-driving-school' ),
        ),
		'section'=> 'vw_driving_school_footer',
		'setting'=> 'vw_driving_school_footer_text',
		'type'=> 'text'
	));	
}

add_action( 'customize_register', 'vw_driving_school_customize_register' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Driving_School_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Driving_School_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new VW_Driving_School_Customize_Section_Pro(
				$manager,
				'example_1',
				array(
					'priority'   => 9,
					'title'    => esc_html__( 'DRIVING SCHOOL PRO', 'vw-driving-school' ),
					'pro_text' => esc_html__( 'GO PRO', 'vw-driving-school' ),
					'pro_url'  => esc_url('https://www.vwthemes.com/themes/driving-school-wordpress-theme/'),
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-driving-school-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-driving-school-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Driving_School_Customize::get_instance();